
.. _finding_galaxy_collections:

*****************************
Finding collections on Galaxy
*****************************

To find collections on Galaxy:

#. Click the :guilabel:`Search` icon in the left-hand navigation.
#. Set the filter to *collection*.
#. Set other filters and press *enter*.

Galaxy presents a list of collections that match your search criteria.
